<?php

namespace App\Http\Controllers;

use App\Imports\ResultsImport;
use App\Imports\ResultPrepareImport;
use App\Result;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Maatwebsite\Excel\Facades\Excel;
use Illuminate\Support\Facades\Validator;
use Illuminate\Http\Request;
use Redirect;
use Response;

class ResultController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
        ini_set('max_execution_time', 1200);
        ini_set('memory_limit', '2048M');
        ini_set('max_input_time', 1200);
        ini_set('post_max_size', '500M');
        ini_set('upload_max_filesize', '500M');
    }

    public function admin_dashboard()
    {
        return view('admin.pages.dashboard');
    }

    public function student_dashboard()
    {
        $matric = Auth::user()->username;

        $sessions = DB::table('results')
            ->where([
                ['matric', $matric],
                ['is_show', 1]
            ])
             ->select('session')
            ->distinct()->get();

        $results = DB::table('results')
            ->select('matric', 'session', 'semester')
            ->groupBy('session', 'semester')
            ->where([
                ['matric', $matric],
                ['is_show', 1]
            ])
            ->get();

        $session_count = $sessions->count();

        $intDiv = intdiv($session_count, 4);

        $last_row_columns = fmod($session_count, 4);

        $i = 0;
        $vect_sessions = array();
        foreach ($sessions as $session) {
            $vect_sessions[$i++] = $session->session;
        }

        rsort($vect_sessions);

        $count = 0;
        $rows = 0;
        $mat_sessions = array();
        for ($i = 1; $i <= $intDiv; $i++) {
            for ($j = 0; $j < 4; $j++) {
                $mat_sessions[$rows][$j] = $vect_sessions[$count++];
            }
            $rows++;
        }

        if ($last_row_columns > 0) {
            for ($j = 0; $j < $last_row_columns; $j++) {
                $mat_sessions[$rows][$j] = $vect_sessions[$count++];
            }
        }

        return view('student.dashboard', compact('results', 'sessions', 'session_count', 'mat_sessions'));

    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show1()
    {

        //$payslip = Payslip::find($id);

        return view('student.result1');
    }

    public function show2()
    {

        //$payslip = Payslip::find($id);

        return view('student.result2');
    }

    public function show($session, $semester)
    {
        $matric = Auth::user()->username;
        $grades = Result::where([
            ['matric', $matric],
            ['session', $session],
            ['semester', $semester],
            ['is_show', 1]
        ])->orderBy('course_code', 'asc')
            ->get();

        $record = Result::where([
            ['matric', $matric],
            ['session', $session],
            ['semester', $semester],
            ['is_show', 1]
        ])->first();

        return view('student.result', compact('grades', 'record'));
    }

    public function uploadindex()
    {
        return view('admin.pages.uploadresults');
    }

    public function import()
    {

        $validator = Validator::make(request()->all(), [
            'file' => 'required'
        ]);

        if ($validator->fails()) {
            return response()->json(['type' => 'error', 'errors'=>$validator->errors()->all()]);
        }else{
            Excel::import(new ResultPrepareImport,request()->file('file'));
            Excel::import(new ResultsImport,request()->file('file'));
            return response()->json(['type' => 'success', 'message' => 'Users uploaded successfully.']);
        }
    }

    public function manage_results(Request $request){
//return $request->all();
        if ($request->ajax()) {

            $students = Result::where([
                ['department_name','like', $request->department_name],
                ['degree_name','like', $request->degree_name],
                ['session', $request->resultsession],
                ['semester', $request->semester]
            ])
                ->select('matric', 'name', 'degree_name', 'department_name', 'is_show')
                ->distinct()
                ->get();
            $view = view('admin.pages.load_result_data', compact('students'))->render();
            return Response::json(['html' => $view]);
        }

        return view('admin.pages.manageresults');
    }

    public function loadFaculties()
    {

        $faculties = DB::table('faculties')->select('id', 'name')
            ->distinct()
            ->where('IsOtherInstitutes', 2)->get();
        $result = "";

        if ($faculties->count() > 1)
            $result .= "<option value='%'>All Faculties</option>";

        foreach($faculties as $faculty) {
            $result .= "<option value='" . $faculty->id . "'>$faculty->name</option>";
        }
        return $result;
    }

    public function loadDepartments(Request $request) {
        $departments = DB::table('departments')
            ->join('faculties', 'departments.facultyid', '=', 'faculties.id')
            ->where([
                ['departments.facultyid', 'like' ,$request->facultyid],
                ['IsOtherInstitutes', '=', 2],
                ['depttype', '=', 2]
            ])
            ->select('departments.id', 'departments.name')
            ->distinct()
            ->orderBy('departments.name', 'asc')
            ->get();

        $result = "";

        if ($departments->count() > 1)
            $result .= "<option value='%'>All Departments</option>";

        foreach($departments as $department) {
            $result .= "<option value='" . $department->id . "'>$department->name</option>";
        }
        return $result;

    }

    public function loadProgrammeTypes(Request $request) {

        $programme_types = DB::table('programme_types')
       ->join('programmes', 'programme_types.id', '=', 'programmes.programmetypeid')
       ->select('programme_types.id', 'programme_types.progtypename')
            ->distinct()
            ->where('programmes.departmentid', 'like', $request->departmentid)
            ->orderBy('progtypename', 'asc')
            ->get();

        $result = "";

        if ($programme_types->count() > 1)
            $result .= "<option value='%'>All Programme Types</option>";

        foreach($programme_types as $programme_type) {
            $result .= "<option value='" . $programme_type->id . "'>$programme_type->progtypename</option>";
        }
        return $result;
    }

   public function loadProgrammes(Request $request) {

        $programmes = DB::table('programmes')
           ->join('departments', 'programmes.departmentid', '=', 'departments.id')
           ->where([
               ['departments.facultyid', 'like' ,$request->facultyid],
               ['programmes.departmentid', 'like', $request->departmentid],
               ['programmes.programmetypeid', 'like', $request->programmetypeid]
           ])
           ->select('programmes.id', 'programmes.name')
            ->distinct()
            ->orderBy('name', 'asc')
           ->get();

       $result = "";

       if ($programmes->count() > 1)
           $result .= "<option value='%'>All Programme Types</option>";

       foreach($programmes as $programme) {
           $result .= "<option value='" . $programme->id . "'>$programme->name</option>";
       }
       return $result;

    }

    public function filter_sessions(){
        $sessions = DB::table('results')
            ->select('session')
            ->distinct()
            ->orderBy('session', 'asc')
            ->get();

        $result = "";

        /*
        if ($schools->count() > 1)
            $result .= "<option value='%'>All Schools</option>";
        */

        foreach ($sessions as $session) {
            $result .= "<option value='" . $session->session . "'>".$session->session."/".($session->session+1)."</option>";
        }

        return $result;
    }

    public function change_result_status(Request $request){
 //return $request->all();
             Result::where('session', $request->resultsession)
                ->where('semester', $request->semester)
                ->update(['is_show' => 0]);
//return $request->arrstudentid;
//return count($request->arrstudentid);
if(count($request->arrstudentid)) {
    //foreach ($request->arrstudentid as $matric) {
        Result::whereIn('matric', $request->arrstudentid)
            ->where('session', $request->resultsession)
            ->where('semester', $request->semester)
            ->update(['is_show' => 1]);
    //}
}
        return Response::json(['type' => 'success', 'message' => "<div class='alert alert-success'>Successfully Save</div>"]);
    }

    public function get_departments(){
       $departments = Result::select('department_name')->distinct()->get();
       $result = "";

        if ($departments->count() > 1)
            $result .= "<option value='%'>All Departments</option>";

        foreach ($departments as $department) {
            $result .= "<option value='" . $department->department_name . "'>".$department->department_name."</option>";
        }

        return $result;
    }

    public function get_programmes(Request $request){
        //return $request->all();
        $programmes = Result::select('degree_name')->distinct()->where('department_name', $request->department_name)->get();

        $result = "";

        if ($programmes->count() > 1)
            $result .= "<option value='%'>All Programmes</option>";

        foreach ($programmes as $programme) {
            $result .= "<option value='" . $programme->degree_name . "'>".$programme->degree_name."</option>";
        }

        return $result;
    }

}
